@@ -24,6 +24,9 @@ from defaults.defaults import get_pluralized_form
 import plugin_loader, plugin, plugin_gui
 from threadManager import get_thread_manager, get_thread_manager_gui, SuspendableThread
 
+UNDO = 1
+SHOW_TRASH = 2
+
 try:
     from exporters import rtf_exporter
     rtf=True
@@ -990,7 +993,7 @@ class RecGui (RecIndex, GourmetApplication, ImporterExporter, StuffThatShouldBeP
         self.main.pack_start(mb,fill=False,expand=False)
         tb = self.ui_manager.get_widget('/RecipeIndexToolBar')
         self.main.pack_start(tb,fill=False,expand=False)
-        self.messagebox = gtk.HBox()
+        self.messagebox = gtk.VBox()
         self.main.pack_start(self.messagebox,fill=False,expand=False)
         self.main_notebook = gtk.Notebook()
         self.recipe_index_interface = self.ui.get_object('recipeIndexBox')
@@ -1034,17 +1037,17 @@ class RecGui (RecIndex, GourmetApplication, ImporterExporter, StuffThatShouldBeP
             ('DeleteRec',gtk.STOCK_DELETE,_('Delete recipe'),
              None,_('Delete selected recipes'),self.rec_tree_delete_rec_cb),
             ('EditRec',gtk.STOCK_EDIT,_('Edit recipe'),
-             None,_('Open selected recipes in recipe editor view'),
+             '<Control>E',_('Open selected recipes in recipe editor view'),
              self.rec_tree_edit_rec),
             ('ExportSelected',None,_('E_xport selected recipes'),
-             None,_('Export selected recipes to file'),
+             '<Control>T',_('Export selected recipes to file'),
              lambda *args: self.do_export(export_all=False)),
             ('Print',gtk.STOCK_PRINT,_('_Print'),
              '<Control>P',None,self.print_recs),
             #('Email', None, _('E-_mail recipes'),
             #None,None,self.email_recs),
             ('BatchEdit',None,_('Batch _edit recipes'),
-             '<Control>E',None,self.batch_edit_recs),
+             '<Control><Shift>E',None,self.batch_edit_recs),
             ('ShopRec','add-to-shopping-list',None,None,None,self.shop_recs)
             ])
 
@@ -1061,11 +1064,11 @@ class RecGui (RecIndex, GourmetApplication, ImporterExporter, StuffThatShouldBeP
             ('Help',gtk.STOCK_HELP,_('_Help'),
              None,None,self.show_help),
             ('ImportFile',None,_('_Import file'),
-             None,_('Import recipe from file'),self.do_import),
+             '<Control>M',_('Import recipe from file'),self.do_import),
             ('ImportWeb',None,_('Import _webpage'),
-             None,_('Import recipe from webpage'),self.import_webpageg),
+             '<Control><Shift>M',_('Import recipe from webpage'),self.import_webpageg),
             ('ExportAll',None,_('Export _all recipes'),
-             None,_('Export all recipes to file'),lambda *args: self.do_export(export_all=True)),
+             '<Control><Shift>T',_('Export all recipes to file'),lambda *args: self.do_export(export_all=True)),
             ('Plugins',None,_('_Plugins'),
              None,_('Manage plugins which add extra functionality to Gourmet.'),
              lambda *args: plugin_gui.show_plugin_chooser()),
@@ -1258,7 +1261,7 @@ class RecGui (RecIndex, GourmetApplication, ImporterExporter, StuffThatShouldBeP
             tm = get_thread_manager()
             tmg = get_thread_manager_gui()
             tm.add_thread(deleterThread)
-            tmg.register_thread_with_dialog(_('Delete Recipes'),deleterThread)
+            tmg.register_thread_with_dialog(_('Delete Recipes'),_('Recipes deleted'),deleterThread)
             tmg.show()
         else:
             return True
@@ -1293,68 +1296,36 @@ class RecGui (RecIndex, GourmetApplication, ImporterExporter, StuffThatShouldBeP
         debug("returning None",2)
         return None
 
+    def _on_bar_response(self, button, response_id):
+        if (response_id == UNDO):
+            self.history[-1].inverse()
+        elif (response_id == SHOW_TRASH):
+            self.show_deleted_recs()
+        self.messagebox.hide()
+
     # Code to show message/undo-button on deletion
     def setup_delete_messagebox (self, msg):
         # Clear existing messages...
         for child in self.messagebox.get_children():
             self.messagebox.remove(child)
         # Add new message
-        l = gtk.Label()
-        close_button = gtk.Button(stock=gtk.STOCK_CLOSE)
-        close_button.connect('clicked',lambda *args: self.messagebox.hide())
-        self.messagebox.pack_end(close_button,expand=False,fill=False)
-        undo_button = gtk.Button(stock=gtk.STOCK_UNDO)
-        show_trash_button = gtk.Button('See Trash Now')
-        show_trash_button.connect('clicked',lambda *args: self.show_deleted_recs() or self.messagebox.hide())
-        undo_button.connect('clicked',lambda *args: self.history[-1].inverse() or self.messagebox.hide())
-        self.messagebox.pack_end(undo_button,expand=False,fill=False)
-        self.messagebox.pack_end(show_trash_button,expand=False,fill=False)
-        self.messagebox.pack_start(l,fill=True,expand=True)
-        self.messagebox.show_all()
-        l.set_markup('<i><span background="yellow">'+msg+'</span></i>')
+        l = gtk.Label(msg)
         l.set_line_wrap(True)
+        l.show()
+        infobar = gtk.InfoBar()
+        infobar.set_message_type(gtk.MESSAGE_INFO)
+        infobar.get_content_area().add(l)
+        infobar.add_button(_('See Trash Now'), SHOW_TRASH)
+        infobar.add_button(gtk.STOCK_UNDO, UNDO)
+        infobar.add_button(gtk.STOCK_DISCARD, gtk.RESPONSE_CLOSE)
+        infobar.connect('response', self._on_bar_response)
+        infobar.show()
+        self.messagebox.pack_start(infobar)
+        self.messagebox.show()
     # end deletion
 
     # end Extra Callbacks for actions on treeview
 
-    def after_dialog_offer_url (self, linktype, file):
-        url = "file:///%s"%file
-        label = _("Export succeeded")
-        if linktype == exporters.WEBPAGE:
-            url += '/index.htm'
-            linktype = _("webpage")
-        sublabel = _("Exported %s to %s")%(linktype,file)
-        def offerer (t):
-            if t.completed:
-                #self.idle_offer_url(label, sublabel, url, True)
-                self.offer_url(label, sublabel, url, True)
-        return offerer
-
-    def idle_offer_url (self, label, sublabl, url, from_thread):
-        if from_thread:
-            gt.gtk_enter()
-        gobject.idle_add(lambda *args: self.offer_url(label,sublabl,url,True))
-        if from_thread:
-            gt.gtk_leave()
-
-    def offer_url (self, label, sublabel, url, from_thread=False):
-        if from_thread:
-            gt.gtk_enter()
-        if hasattr(self,'progress_dialog'):
-            self.hide_progress_dialog()            
-        d=de.MessageDialog(label=label,
-                           sublabel=sublabel,
-                           cancel=False,
-                           modal=False
-                           )
-        b = gtk.Button(stock=gtk.STOCK_JUMP_TO)
-        b.connect('clicked',lambda *args: launch_url(url))
-        d.vbox.pack_end(b,expand=False)
-        b.show()
-        d.run()
-        if from_thread:
-            gt.gtk_leave()
-
     # Methods to handle threading
     def pause_cb (self, button, *args):
         if button.get_active():
